@@ -12,6 +12,36 @@
 #*          DESCRIPTION  :   Object Oriented interface to /proc/cpuinfo
 #*
 #*****************************************************************************
+#*
+#*          $Log: Cpuinfo.pm,v $
+#*          Revision 1.7  2004/09/27 12:31:23  jonathan
+#*          * Small changes from Tels
+#*          * Rearranging source
+#*
+#*          Revision 1.6  2004/06/24 16:36:14  jonathan
+#*          * Fixed typo in the example of num_cpus
+#*
+#*          Revision 1.5  2002/06/10 12:21:58  gellyfish
+#*          Change to failure mode of accessors suggested by Tels
+#*
+#*          Revision 1.4  2002/01/29 21:47:12  gellyfish
+#*          * Closing CPUINFO as reported by tels :)
+#*
+#*          Revision 1.3  2001/09/11 07:23:16  gellyfish
+#*          * Applied kindly patch from Tels
+#*          * Added proper SMP support
+#*          * Test for SMP support
+#*
+#*
+#*          Revision 1.2  2001/06/17 21:28:26  gellyfish
+#*          Ooh forgot the documentation
+#*
+#*          Revision 1.1  2001/06/17 12:40:16  gellyfish
+#*          Checked into CVS for first release
+#*
+#*
+#*
+#*****************************************************************************/
 
 package Linux::Cpuinfo;
 
@@ -69,19 +99,18 @@ the recommended one.
 
 =cut
 
-use 5.006;
+use 5.00503;
 
 use strict;
-use warnings;
 
 use Carp;
 
+use vars qw(
+  $VERSION
+  $AUTOLOAD
+);
 
-our $AUTOLOAD;
-
-our  $VERSION = '1.12';
-
-$VERSION = eval $VERSION;
+($VERSION) = q$Revision: 1.7 $ =~ /([\d.]+)/;
 
 =item cpuinfo
 
@@ -135,6 +164,7 @@ sub cpuinfo
             {
                 chomp;
 
+                $self->{_private}->{num_cpus}++;
 
                 my $cpuinfo = {};
 
@@ -145,7 +175,7 @@ sub cpuinfo
                     $attribute =~ s/\s+/_/;
                     $attribute = lc($attribute);
 
-                    if ( $value && $value =~ /^(no|not available|yes)$/ )
+                    if ( $value =~ /^(no|not available|yes)$/ )
                     {
                         $value = $value eq 'yes' ? 1 : 0;
                     }
@@ -160,31 +190,8 @@ sub cpuinfo
                     }
 
                 }
-                # This is a lot uglier than it needs to be. The perl 6
-                # version is 6 lines.
-                # It seems that single core arm6 or 7 cores highlight
-                # a bug where there is a spurious \n in there
-                # The alert will correctly surmise this breaks for assymetric 
-                # cpus
-                
-                my $ok_to_add = 1;
-                if ( @{ $self->{_cpuinfo} } )
-                {
-                   if (keys %{$self->{_cpuinfo}->[-1]->{_data}} != keys %{$cpuinfo} )
-                   {
-                      foreach my $key ( keys %{$cpuinfo} )
-                      {
-                         $self->{_cpuinfo}->[-1]->{_data}->{$key} = $cpuinfo->{$key};
-                      }
-                      $ok_to_add = 0;
-                   }
-                }
-                if ( $ok_to_add )
-                {
-                   my $cpuinfo_cpu = Linux::Cpuinfo::Cpu->new( $cpuinfo, $args );
-                   $self->{_private}->{num_cpus}++;
-                   push @{ $self->{_cpuinfo} }, $cpuinfo_cpu;
-                }
+                my $cpuinfo_cpu = Linux::Cpuinfo::Cpu->new( $cpuinfo, $args );
+                push @{ $self->{_cpuinfo} }, $cpuinfo_cpu;
             }
 
             bless $self, $class;
@@ -406,7 +413,7 @@ package Linux::Cpuinfo::Cpu;
 use strict;
 use Carp;
 
-our $AUTOLOAD;
+use vars qw($AUTOLOAD);
 
 sub new
 {
@@ -481,19 +488,13 @@ the contents of C</proc/cpuinfo > are different for different processors.
 I really would be indebted if Linux users from other than x86 processors
 would help me document this properly.
 
-The source can be found at
-
-    https://github.com/jonathanstowe/Linux-Cpuinfo
-
-Please feel free to fork, send patches etc.
-
 =head1 COPYRIGHT AND LICENSE
 
 See the README file in the Distribution Kit
 
 =head1 AUTHOR
 
-Jonathan Stowe, E<lt>jns@gellyfish.co.ukE<gt>
+Jonathan Stowe, E<lt>gellyfish@gellyfish.comE<gt>
 
 =head1 SEE ALSO
 
